#
# spec file for package maven-javadoc-plugin
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor bootstrap%{nil}
%if "%{flavor}" == "bootstrap"
%bcond_without bootstrap
%else
%bcond_with bootstrap
%endif
%global base_name maven-javadoc-plugin
Version:        3.6.0
Release:        slfo.1.3.4
Summary:        Maven plugin for creating javadocs
License:        Apache-2.0
Group:          Development/Libraries/Java
URL:            https://maven.apache.org/plugins/maven-javadoc-plugin
Source0:        https://repo1.maven.org/maven2/org/apache/maven/plugins/%{base_name}/%{version}/%{base_name}-%{version}-source-release.zip
Source1:        %{base_name}-build.xml
Patch0:         %{base_name}-bootstrap-resources.patch
Patch1:         stale-data-encoding.patch
Patch2:         no-override.patch
BuildRequires:  apache-commons-lang3
BuildRequires:  apache-commons-text
BuildRequires:  atinject
BuildRequires:  fdupes
BuildRequires:  httpcomponents-client
BuildRequires:  httpcomponents-core
BuildRequires:  javapackages-local
BuildRequires:  maven-archiver
BuildRequires:  maven-common-artifact-filters
BuildRequires:  maven-doxia-core
BuildRequires:  maven-doxia-logging-api
BuildRequires:  maven-doxia-module-xhtml
BuildRequires:  maven-doxia-sink-api
BuildRequires:  maven-doxia-sitetools
BuildRequires:  maven-invoker
BuildRequires:  maven-lib
BuildRequires:  maven-plugin-annotations
BuildRequires:  maven-reporting-api >= 3.1.0
BuildRequires:  maven-resolver-api
BuildRequires:  maven-resolver-util
BuildRequires:  maven-shared-utils
BuildRequires:  maven-wagon-provider-api
BuildRequires:  plexus-archiver
BuildRequires:  plexus-interactivity-api
BuildRequires:  plexus-io
BuildRequires:  plexus-languages
BuildRequires:  plexus-utils
BuildRequires:  plexus-xml
BuildRequires:  qdox
BuildRequires:  sisu-inject
BuildRequires:  sisu-plexus
BuildRequires:  unzip
BuildRequires:  xmvn-install
BuildRequires:  xmvn-resolve
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:)
BuildArch:      noarch
%if %{with bootstrap}
Name:           %{base_name}-bootstrap
VCS: https://src.suse.de/SLFO-pool/maven-javadoc-plugin#318342dad7941ecde7de79312eedfa65778539b291d7e3d7afc3496cc6fc82f8
BuildRequires:  ant
BuildRequires:  modello >= 2.0.0
%else
Name:           %{base_name}
VCS: https://src.suse.de/SLFO-pool/maven-javadoc-plugin#318342dad7941ecde7de79312eedfa65778539b291d7e3d7afc3496cc6fc82f8
BuildRequires:  xmvn
BuildRequires:  mvn(org.apache.maven.plugins:maven-compiler-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-jar-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-javadoc-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugin-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-plugins:pom:) >= 40
BuildRequires:  mvn(org.apache.maven.plugins:maven-resources-plugin)
BuildRequires:  mvn(org.apache.maven.plugins:maven-surefire-plugin)
BuildRequires:  mvn(org.codehaus.modello:modello-maven-plugin)
BuildRequires:  mvn(org.eclipse.sisu:sisu-maven-plugin)
Obsoletes:      %{base_name}-bootstrap
#!BuildRequires: maven-compiler-plugin-bootstrap
#!BuildRequires: maven-jar-plugin-bootstrap
#!BuildRequires: maven-javadoc-plugin-bootstrap
#!BuildRequires: maven-plugin-plugin-bootstrap
#!BuildRequires: maven-resources-plugin-bootstrap
#!BuildRequires: maven-surefire-plugin-bootstrap
%endif

%description
The Maven Javadoc Plugin is a plugin that uses the javadoc tool for
generating javadocs for the specified project.

%if %{without bootstrap}
%package javadoc
Summary:        Javadoc for %{name}
Group:          Documentation/HTML

%description javadoc
API documentation for %{name}.
%endif

%prep
%setup -q -n %{base_name}-%{version}
%if %{with bootstrap}
cp %{SOURCE1} build.xml
%patch -P 0 -p1
%endif
%patch -P 1 -p1
%patch -P 2 -p1

%pom_add_dep org.codehaus.plexus:plexus-xml:3.0.0

%pom_xpath_remove pom:project/pom:parent/pom:relativePath
%pom_remove_dep :::test:

%build
%if %{with bootstrap}
mkdir -p lib
build-jar-repository -s lib \
    apache-commons-lang3 \
    apache-commons-text \
    atinject \
    httpcomponents/httpclient \
    httpcomponents/httpcore \
    maven-archiver/maven-archiver \
    maven-common-artifact-filters/maven-common-artifact-filters \
    maven-doxia/doxia-core \
    maven-doxia/doxia-logging-api \
    maven-doxia/doxia-module-xhtml \
    maven-doxia/doxia-module-xhtml5 \
    maven-doxia/doxia-sink-api \
    maven-doxia-sitetools/doxia-site-renderer \
    maven-invoker/maven-invoker \
    maven/maven-artifact \
    maven/maven-core \
    maven/maven-model \
    maven/maven-model-builder \
    maven/maven-plugin-api \
    maven/maven-settings \
    maven-plugin-tools/maven-plugin-annotations \
    maven-resolver/maven-resolver-api \
    maven-resolver/maven-resolver-util \
    maven-reporting-api/maven-reporting-api \
    maven-shared-utils/maven-shared-utils \
    maven-wagon/provider-api \
    org.eclipse.sisu.inject \
    org.eclipse.sisu.plexus \
    plexus/archiver \
    plexus/interactivity-api \
    plexus/io \
    plexus-languages/plexus-java \
    plexus/utils \
    plexus/xml \
    qdox
%{ant} -Dtest.skip=true jar
%else
xmvn --batch-mode --offline \
    -Dmaven.test.skip=true -DmavenVersion=3.5.0 \
%if %{?pkg_vcmp:%pkg_vcmp java-devel >= 9}%{!?pkg_vcmp:0}
    -Dmaven.compiler.release=8 \
%endif
    package org.apache.maven.plugins:maven-javadoc-plugin:aggregate
%endif

%{mvn_artifact} pom.xml target/%{base_name}-%{version}.jar

%install
%mvn_install
%fdupes -s %{buildroot}%{_javadocdir}

%files -f .mfiles
%license LICENSE
%doc NOTICE

%if %{without bootstrap}
%files javadoc -f .mfiles-javadoc
%license LICENSE
%doc NOTICE
%endif

%changelog
* Mon Jun 10 2024 fstrba@suse.com
- Remove dependency on plexus-metadata-generator,
  plexus-component-metadata and on their dependencies, since there
  is no plexus @Component annotation any more
* Tue Apr  2 2024 fstrba@suse.com
- Add dependency on plexus-xml where relevant
  * this will be needed for smooth upgrade to plexus-utils 4.0.0
* Wed Feb 21 2024 fstrba@suse.com
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jan 26 2024 fstrba@suse.com
- Require maven-parent >= 40. The maven build will fail with
  anything lower
* Wed Sep 20 2023 fstrba@suse.com
- Upgrade to upstream version 3.6.0
  * Bug
    + MJAVADOC-642: Setting maven.javadoc.isoffline seems to have no
    effect
    + MJAVADOC-701: javadoc site is broken for projects that contain
    modules
    + MJAVADOC-733: Alternative doclet page points to an SEO spammy
    page
    + MJAVADOC-742: [REGRESSION] Transitive dependencies of
    docletArtifact missing
    + MJAVADOC-757: Unresolvable link in javadoc tag with value
    ResourcesBundleMojo#getAttachmentClassifier() found in
    ResourcesBundleMojo
    + MJAVADOC-758: IOException --> NullPointerException in
    JavadocUtil.copyResource
    + MJAVADOC-763: JavadocReportTest.testExceptions is broken
    + MJAVADOC-767: javadoc creates invalid --patch-module
    statements
    + MJAVADOC-769: javadoc plugin can not deal with transitive
    filename based modules
  * Improvement
    + MJAVADOC-755: Clean up deprecated and unpreferred methods in
    JavadocUtil
    + MJAVADOC-760: Cleanup dependency declarations as best possible
    + MJAVADOC-770: Allow building javadoc "the old fashioned way"
    after Java 8
  * Task
    + MJAVADOC-743: Drop use of deprecated localRepository mojo
    parameter
    + MJAVADOC-765: Make build pass with Java 20
    + MJAVADOC-772: Refresh download page
  * Dependency upgrade
    + MJAVADOC-761: Update to commons-io 2.13.0
    + MJAVADOC-766: Update plexus-archiver from 4.7.1 to 4.8.0
    + MJAVADOC-771: Upgrade Parent to 40
- Modified patches:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + regenerate in cycle
  * no-override.patch
  * stale-data-encoding.patch
    + rediff to changed line-endings
* Wed Sep 20 2023 fstrba@suse.com
- Upgrade to upstream version 3.5.0
  * Bug
    + MJAVADOC-696: Invalid anchors in Javadoc and plugin mojo
    + MJAVADOC-700: Plugin duplicates classes in Java 8 all-classes
    lists
    + MJAVADOC-702: javadoc site creation ignores configuration
    parameters
  * Improvement
    + MJAVADOC-685: Deprecate parameter "stylesheet"
    + MJAVADOC-721: Parse stderr output and suppress informational
    lines
    + MJAVADOC-729: Link to Javadoc references from JDK 17
    + MJAVADOC-731: Migrate components to JSR 330, get rid of
    maven-artifact-transfer, update to parent 37
  * Task
    + MJAVADOC-712: Remove remains of org.codehaus.doxia.sink.Sink
  * Dependency upgrade
    + MJAVADOC-711: Upgrade plugins in ITs
    + MJAVADOC-714: Upgrade to Maven 3.2.5
    + MJAVADOC-719: Update Maven Archiver to 3.6.0
    + MJAVADOC-723: Upgrade Maven Reporting API to 3.1.1/Complete
    with Maven Reporting Impl 3.2.0
    + MJAVADOC-738: Upgrade commons-text to 1.10.0
    + MJAVADOC-740: Upgrade Parent to 39
    + MJAVADOC-741: Upgrade plugins and components
- Modified patches:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + regenerate in cycle
  * stale-data-encoding.patch
    + rediff to changed context
- Added patch:
  * no-override.patch
    + allow building with older version of maven-reporting-api
- Removed patch:
  * maven-javadoc-plugin-ioexception.patch
    + not necessary with this version
* Tue Oct 25 2022 fstrba@suse.com
- Added patch:
  * maven-javadoc-plugin-ioexception.patch
    + allow building with wider range of plexus-utils versions,
    including the 3.5.0 that does not declare IOException as
    thrown in functions where it is actually not thrown.
* Fri May 13 2022 fstrba@suse.com
- Fix build with modello 2.0.0
* Mon Mar 14 2022 fstrba@suse.com
- Added patch:
  * stale-data-encoding.patch
    + use the same encoding when writing and getting the stale data
    + fixes build with utf-8 sources on non utf-8 platforms
* Fri Mar 11 2022 fstrba@suse.com
- Upgrade to upstream version 3.3.2
  * fixing several NPE errors and using new
    maven-reporting-{api,impl}
- Removed patches:
  * 0001-Port-to-current-plexus-utils.patch
  * reproducible-footer.patch
    + not needed with the upstream code
- Modified patch:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + regenerate the resources to correspond to the new version
* Tue May 11 2021 fstrba@suse.com
- Do not build against the legacy guava20 package any more
* Wed Mar 11 2020 fstrba@suse.com
- Fix build with doxia 1.9.x
* Sun Nov 24 2019 fstrba@suse.com
- Upgrade to version 3.1.1
- Modified patch:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + Regenerate patch from the non-bootstrap build
* Thu Nov 21 2019 fstrba@suse.com
- Fix build with maven-invoker-3.0.1 that has a new dependency
  on maven-shared-utils
* Mon Oct  7 2019 bwiedemann@suse.com
- Add reproducible-footer.patch to override build date (boo#1047218)
* Sat Apr  6 2019 jengelh@inai.de
- Spruce up summary to not just repeat the name.
* Wed Apr  3 2019 fstrba@suse.com
- Initial packaging of maven-jar-plugin 3.0.1
- Generate and customize ant build.xml file to use with the
  bootstrap variang
- Create as a multibuild package to allow bootstrapping
- Added patch:
  * maven-javadoc-plugin-bootstrap-resources.patch
    + For the bootstrap version, add pre-generated resources that
    need maven-plugin-plugin and maven to be generated at build
    time
